==> kaizen_cloudcode-0.3.0-py3-none-any.whl: kaizen/llms/prompts/code_review_prompts.py <==
CODE_REVIEW_SYSTEM_PROMPT = """
As a senior software developer reviewing code submissions, provide thorough, constructive feedback and suggestions for improvements. Consider best practices, error handling, performance, readability, and maintainability. Offer objective and respectful reviews that help developers enhance their skills and code quality. Use your expertise to provide comprehensive feedback without asking clarifying questions.
"""

CODE_REVIEW_PROMPT = """
As an experienced software engineer reviewing a pull request, provide a concise and actionable code review that evaluates the code changes, identifies potential issues, and offers constructive feedback to the developer.

Generate a code review with feedback organized as a JSON object, including only sections with relevant feedback and omitting sections without feedback. Use the following structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONSICE_COMMENT_ON_WHATS_THE_ISSUE>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "reason": "<YOUR_REASON_FOR_COMMENTING_THIS_ISSUE>"
      "solution": "<SOLUTION_TO_THE_COMMENT>",
      "position": "<POSITION_OF_CODE_LINE_RELATIVE_TO_PATCH>",
      "side": "<LEFT_OR_RIGHT>",
      "file_name": "<FULL_FILE_PATH>",
      "sentiment": "<COMMENT_SENTIMENT_POSITIVE_NEGATIVE_OR_NEUTRAL>",
      "severity_level": <INTEGER_FROM_1_TO_10>
    }},
    ...
  ]
}}

For "position", This is the line number in the diff where the comment should be placed. We count from the start of the diff chunk, including the unchanged lines.
For "side", provide the side as LEFT or RIGHT based on deleted or added lines respectively. Need this for github review comment.
For "file_name" make sure to give the whole path so that developers can know exactly which file has issue.
For "severity_level" score in range of 1 to 10, 1 being not severe and 10 being critical.

Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Potential Issues"
- "Improvements"

Examine the code logic for the following issues:
[
  "Syntax Errors",
  "Logic Errors",
  "Off-by-one Errors",
  "Infinite Loops",
  "Null or Undefined Values",
  "Resource Leaks",
  "Race Conditions",
  "Integration Issues",
  "Performance Issues",
  "Security Vulnerabilities"
]

Set "request_for_change" to true for topics under "Improvements" or "Potential Issues" or any issue requiring the developer's attention.

For "solution", precisely identify the problem and provide a specific fix for the current code.

Generate all relevant and actionable feedback. Merge duplicate feedbacks for the same line. For each piece of feedback, reference the specific file(s) and line number(s) of code being addressed. Use markdown code blocks to quote relevant code snippets when necessary.

Ensure comments are concise yet contain actionable and useful points directly related to the code or line with the issue. Avoid generic comments and duplicate feedback.

If no feedback is necessary, return an empty JSON object: {{"review": []}}

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

Code Diff:
```{CODE_DIFF}```
"""

FILE_CODE_REVIEW_PROMPT = """
As an experienced software engineer reviewing a pull request, provide a concise and actionable code review that evaluates the code changes, identifies potential issues, and offers constructive feedback to the developer.

Generate a code review with feedback organized as a JSON object, including only sections with relevant feedback and omitting sections without feedback. Use the following structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONSICE_COMMENT_ON_WHATS_THE_ISSUE>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "reason": "<YOUR_REASON_FOR_COMMENTING_THIS_ISSUE>"
      "solution": "<SOLUTION_TO_THE_COMMENT>",
      "position": "<POSITION_OF_CODE_LINE_RELATIVE_TO_PATCH>",
      "side": "<LEFT_OR_RIGHT>",
      "file_name": "<FULL_FILE_PATH>",
      "sentiment": "<COMMENT_SENTIMENT_POSITIVE_NEGATIVE_OR_NEUTRAL>",
      "severity_level": <INTEGER_FROM_1_TO_10>
    }},
    ...
  ]
}}

For "position", This is the line number in the diff where the comment should be placed. We count from the start of the diff chunk, including the unchanged lines.For "side", provide the side as LEFT or RIGHT based on deleted or added lines respectively. Need this for github review comment.
For "file_name" make sure to give the whole path so that developers can know exactly which file has issue.
For "severity_level" score in range of 1 to 10, 1 being not severe and 10 being critical.

Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Potential Issues"
- "Improvements"

Examine the code logic for the following issues:
[
  "Syntax Errors",
  "Logic Errors",
  "Off-by-one Errors",
  "Infinite Loops",
  "Null or Undefined Values",
  "Resource Leaks",
  "Race Conditions",
  "Integration Issues",
  "Performance Issues",
  "Security Vulnerabilities"
]

Set "request_for_change" to true for topics under "Improvements" or "Potential Issues" or any issue requiring the developer's attention.

For "solution", precisely identify the problem and provide a specific fix for the current code.

Generate all relevant and actionable feedback. Merge duplicate feedbacks for the same line. For each piece of feedback, reference the specific file(s) and line number(s) of code being addressed. Use markdown code blocks to quote relevant code snippets when necessary.

Ensure comments are concise yet contain actionable and useful points directly related to the code or line with the issue. Avoid generic comments and duplicate feedback.

If no feedback is necessary, return an empty JSON object: {{"review": []}}

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

File PATCH:
```{FILE_PATCH}```
"""

PR_DESCRIPTION_PROMPT = """
As a skilled developer reviewing a pull request, generate a concise and well-formatted description summarizing the main purpose, scope of changes, significant modifications, refactoring, or new features introduced in the pull request.

Provide the output in the following JSON format:

{{
  "desc": "
### Summary

<Brief one-line summary of the pull request>

### Details

<Detailed multi-line description in markdown format>
- List of key changes
- New features
- Refactoring details
  "
}}

When generating the description:

- Create a concise and clear summary highlighting the main purpose of the pull request.
- Use markdown formatting in the detailed description for better readability.
- Organize the details into relevant sections or bullet points.
- Focus on the most significant aspects of the changes.
- Avoid repeating information already present in the pull request title or description.
- Ensure the output is in valid JSON format.

Based on the provided information:

Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}
Code Diff:
{CODE_DIFF}

Analyze the information thoroughly and generate a comprehensive summary and detailed description.
Use your expertise to identify and highlight the most important aspects of the changes without asking for additional clarification. If certain details are unclear, make reasonable inferences based on the available information and your development experience.

"""

PR_FILE_DESCRIPTION_PROMPT = """
As a skilled developer reviewing a pull request, generate a concise and well-formatted description summarizing the main purpose, scope of changes, significant modifications, refactoring, or new features introduced in the pull request.

Provide the output in the following JSON format:

{{
  "desc": "
### Summary

<Brief one-line summary of the pull request>

### Details

<Detailed multi-line description in markdown format>
- List of key changes
- New features
- Refactoring details
  "
}}

When generating the description:

- Create a concise and clear summary highlighting the main purpose of the pull request.
- Use markdown formatting in the detailed description for better readability.
- Organize the details into relevant sections or bullet points.
- Focus on the most significant aspects of the changes.
- Avoid repeating information already present in the pull request title or description.
- Ensure the output is in valid JSON format.

Based on the provided information:

Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}
Code Diff:
{CODE_DIFF}

Analyze the information thoroughly and generate a comprehensive summary and detailed description.
Use your expertise to identify and highlight the most important aspects of the changes without asking for additional clarification. If certain details are unclear, make reasonable inferences based on the available information and your development experience.
"""

MERGE_PR_DESCRIPTION_PROMPT = """
As a skilled developer reviewing a pull request, generate a concise and well-formatted description that synthesizes multiple PR descriptions into a single, comprehensive summary. This summary should encapsulate the main purpose, scope of changes, significant modifications, refactoring, and new features introduced in the pull request.

Using the provided PR descriptions in JSON format, create a merged PR Description in the following JSON format:

{{
  "desc": "
### Summary

<Brief one-line summary encompassing the overall purpose of the pull request>

### Details

<Detailed multi-line description in markdown format>
- Consolidated list of key changes
- Aggregated new features
- Combined refactoring details
- Other significant aspects from all descriptions
  "
}}

When generating the merged description:

- Create a concise yet comprehensive summary that captures the essence of all provided descriptions.
- Use markdown formatting in the detailed description for improved readability.
- Organize the details into relevant sections or bullet points, consolidating similar information from different descriptions.
- Focus on the most significant aspects of the changes across all descriptions.
- Eliminate redundancies and repetitions while ensuring all unique and important points are included.
- Ensure the output is in valid JSON format.

Analyze the provided PR descriptions thoroughly and generate a unified, comprehensive summary and detailed description. Use your expertise to identify, merge, and highlight the most important aspects of the changes across all descriptions. If certain details seem contradictory or unclear, use your best judgment to provide the most accurate and coherent representation of the pull request's purpose and changes.

Here is the information:
{DESCS}
"""

PR_DESC_EVALUATION_PROMPT = """
Please evaluate the accuracy and completeness of your previous responses in this conversation.
Identify any potential errors or areas for improvement.

Respond the JSON output as:
{{
  "desc": "
### Summary

<Brief one-line summary encompassing the overall purpose of the pull request>

### Details

<Detailed multi-line description in markdown format>
- Consolidated list of key changes
- Aggregated new features
- Combined refactoring details
- Other significant aspects from all descriptions
  "
}}

"""


PR_REVIEW_EVALUATION_PROMPT = """
Please evaluate the accuracy and completeness of your previous responses in this conversation.
Fix any potential errors or areas for improvement.

Generate a code review with feedback organized as a JSON object, including only sections with relevant feedback and omitting sections without feedback. Use the following structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONSICE_COMMENT_ON_WHATS_THE_ISSUE>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "reason": "<YOUR_REASON_FOR_COMMENTING_THIS_ISSUE>"
      "solution": "<SOLUTION_TO_THE_COMMENT>",
      "start_line": "<CODE_START_LINE_INTEGER>",
      "end_line": "<CODE_END_LINE_INTEGER>",
      "file_name": "<ABSOLUTE_CODE_FILE_PATH>",
      "request_for_change": "<NEEDS_UPDATE_IN_TRUE_OR_FALSE>"
    }},
    ...
  ]
}}

For "file_name" make sure to give the whole path so that developers can know exactly which file has issue.

Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

"""

==> kaizen_cloudcode-0.3.7-py3-none-any.whl: kaizen/llms/prompts/code_review_prompts.py <==
CODE_REVIEW_SYSTEM_PROMPT = """
As a senior software developer reviewing code submissions, provide thorough, constructive feedback and suggestions for improvements. Consider best practices, error handling, performance, readability, and maintainability. Offer objective and respectful reviews that help developers enhance their skills and code quality. Use your expertise to provide comprehensive feedback without asking clarifying questions.
"""

CODE_REVIEW_PROMPT = """
As an experienced software engineer reviewing a pull request, provide a concise and actionable code review that evaluates the code changes, identifies potential issues, and offers constructive feedback to the developer.

Generate a code review with feedback organized as a JSON object, including only sections with relevant feedback and omitting sections without feedback. Use the following structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONSICE_COMMENT_ON_WHATS_THE_ISSUE>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "reason": "<YOUR_REASON_FOR_COMMENTING_THIS_ISSUE>"
      "solution": "<HIGH_LEVEL_SOLUTION>",
      "fixed_code": "<FIXED_CODE>",
      "start_line": "<CODE_START_LINE_INTEGER>",
      "end_line": "<CODE_END_LINE_INTEGER>",
      "side": "<LEFT_OR_RIGHT>",
      "file_name": "<FULL_FILE_PATH>",
      "sentiment": "<COMMENT_SENTIMENT_POSITIVE_NEGATIVE_OR_NEUTRAL>",
      "severity_level": <INTEGER_FROM_1_TO_10>
    }},
    ...
  ]
}}

For "solution", create a solution comment with high level solution to this issue.
For "fixed_code", generated the fixed code script to replace the commented line. make sure you replace the exact changes code between start_line and end_line.
For "start_line", The first line of the code in that the comment applies to. Make sure "fixed_code" starts from this line.
For "end_line", this is the last line of the code that the comment applies to. Make sure the "fixed_code" ends at this line.
For "side", provide the side as LEFT or RIGHT based on deleted or added lines respectively. Need this for github review comment.
For "file_name" make sure to give the whole path so that developers can know exactly which file has issue.
For "severity_level" score in range of 1 to 10, 1 being not severe and 10 being critical.

Process the given patch data. Identify lines beginning with '+' (excluding the file header line starting with '+++') as additions.
Make sure the "fixed_code" applied to addition lines only.

When generating the description:

- Create a concise and clear summary highlighting the main purpose of the pull request.
- Use markdown formatting in the detailed description for better readability.
- Organize the details into relevant sections or bullet points.
- Focus on the most significant aspects of the changes.
- Avoid repeating information already present in the pull request ti

Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Potential Issues"
- "Improvements"

Examine the code logic for the following issues:
[
  "Syntax Errors",
  "Logic Errors",
  "Off-by-one Errors",
  "Infinite Loops",
  "Null or Undefined Values",
  "Resource Leaks",
  "Race Conditions",
  "Integration Issues",
  "Performance Issues",
  "Security Vulnerabilities"
]


Generate all relevant and actionable feedback. Merge duplicate feedbacks for the same line. For each piece of feedback, reference the specific file(s) and line number(s) of code being addressed. 
Use markdown code blocks to quote relevant code snippets when necessary.

Ensure comments are concise yet contain actionable and useful points directly related to the code or line with the issue. Avoid generic comments.

If no feedback is necessary, return an empty JSON object: {{"review": []}}

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

PATCH DATA:
```{CODE_DIFF}```
"""

FILE_CODE_REVIEW_PROMPT = """
As an experienced software engineer reviewing a pull request, provide a concise and actionable code review that evaluates the code changes, identifies potential issues, and offers constructive feedback to the developer.

Generate a code review with feedback organized as a JSON object, including only sections with relevant feedback and omitting sections without feedback. Use the following structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONSICE_COMMENT_ON_WHATS_THE_ISSUE>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "reason": "<YOUR_REASON_FOR_COMMENTING_THIS_ISSUE>"
      "solution": "<HIGH_LEVEL_SOLUTION>",
      "fixed_code": "<FIXED_CODE>",
      "start_line": "<CODE_START_LINE_INTEGER>",
      "end_line": "<CODE_END_LINE_INTEGER>",
      "side": "<LEFT_OR_RIGHT>",
      "file_name": "<FULL_FILE_PATH>",
      "sentiment": "<COMMENT_SENTIMENT_POSITIVE_NEGATIVE_OR_NEUTRAL>",
      "severity_level": <INTEGER_FROM_1_TO_10>
    }},
    ...
  ],
    "desc": "
### Summary

<Brief one-line summary of the pull request>

### Details

<Detailed multi-line description in markdown format>
- List of key changes
- New features
- Refactoring details
  "
}}

For "solution", create a solution comment with high level solution to this issue.
For "fixed_code", generated the fixed code script to replace the commented line. make sure you replace the exact changes code between start_line and end_line.
For "start_line", The first line of the code in that the comment applies to. Make sure "fixed_code" starts from this line.
For "end_line", this is the last line of the code that the comment applies to. Make sure the "fixed_code" ends at this line.
For "side", provide the side as LEFT or RIGHT based on deleted or added lines respectively. Need this for github review comment.
For "file_name" make sure to give the whole path so that developers can know exactly which file has issue.
For "severity_level" score in range of 1 to 10, 1 being not severe and 10 being critical.

Process the given patch data. Identify lines beginning with '+' (excluding the file header line starting with '+++') as additions
Make sure the "fixed_code" applied to addition lines only.

When generating the description:

- Create a concise and clear summary highlighting the main purpose of the pull request.
- Use markdown formatting in the detailed description for better readability.
- Organize the details into relevant sections or bullet points.
- Focus on the most significant aspects of the changes.
- Avoid repeating information already present in the pull request title or description.
- Ensure the output is in valid JSON format.

Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

Potential section topics:
- "Code Quality"
- "Performance" 
- "Potential Issues"
- "Improvements"

Examine the code logic for the following issues:
[
  "Syntax Errors",
  "Logic Errors",
  "Off-by-one Errors",
  "Infinite Loops",
  "Null or Undefined Values",
  "Resource Leaks",
  "Race Conditions",
  "Integration Issues",
  "Performance Issues",
  "Security Vulnerabilities"
]


Generate all relevant and actionable feedback. Merge duplicate feedbacks for the same line. For each piece of feedback, reference the specific file(s) and line number(s) of code being addressed. 
Use markdown code blocks to quote relevant code snippets when necessary.

Ensure comments are concise yet contain actionable and useful points directly related to the code or line with the issue. Avoid generic comments.

If no feedback is necessary, return an empty JSON object: {{"review": []}}

INFORMATION:
Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}

File PATCH:
```{FILE_PATCH}```
"""

PR_DESCRIPTION_PROMPT = """
As a skilled developer reviewing a pull request, generate a concise and well-formatted description summarizing the main purpose, scope of changes, significant modifications, refactoring, or new features introduced in the pull request.

Provide the output in the following JSON format:

{{
  "desc": "
### Summary

<Brief one-line summary of the pull request>

### Details

<Detailed multi-line description in markdown format>
- List of key changes
- New features
- Refactoring details
  "
}}

When generating the description:

- Create a concise and clear summary highlighting the main purpose of the pull request.
- Use markdown formatting in the detailed description for better readability.
- Organize the details into relevant sections or bullet points.
- Focus on the most significant aspects of the changes.
- Avoid repeating information already present in the pull request title or description.
- Ensure the output is in valid JSON format.

Based on the provided information:

Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}
Patch Data:
{CODE_DIFF}

Analyze the information thoroughly and generate a comprehensive summary and detailed description.
Use your expertise to identify and highlight the most important aspects of the changes without asking for additional clarification. If certain details are unclear, make reasonable inferences based on the available information and your development experience.

"""

PR_FILE_DESCRIPTION_PROMPT = """
As a skilled developer reviewing a pull request, generate a concise and well-formatted description summarizing the main purpose, scope of changes, significant modifications, refactoring, or new features introduced in the pull request.

Provide the output in the following JSON format:

{{
  "desc": "
### Summary

<Brief one-line summary of the pull request>

### Details

<Detailed multi-line description in markdown format>
- List of key changes
- New features
- Refactoring details
  "
}}

When generating the description:

- Create a concise and clear summary highlighting the main purpose of the pull request.
- Use markdown formatting in the detailed description for better readability.
- Organize the details into relevant sections or bullet points.
- Focus on the most significant aspects of the changes.
- Avoid repeating information already present in the pull request title or description.
- Ensure the output is in valid JSON format.

Based on the provided information:

Pull Request Title: {PULL_REQUEST_TITLE}
Pull Request Description: {PULL_REQUEST_DESC}
Patch Data:
{CODE_DIFF}

Analyze the information thoroughly and generate a comprehensive summary and detailed description.
Use your expertise to identify and highlight the most important aspects of the changes without asking for additional clarification. If certain details are unclear, make reasonable inferences based on the available information and your development experience.
"""

MERGE_PR_DESCRIPTION_PROMPT = """
As a skilled developer reviewing a pull request, generate a concise and well-formatted description that synthesizes multiple PR descriptions into a single, comprehensive summary. This summary should encapsulate the main purpose, scope of changes, significant modifications, refactoring, and new features introduced in the pull request.

Using the provided PR descriptions in JSON format, create a merged PR Description in the following JSON format:

{{
  "desc": "
### Summary

<Brief one-line summary encompassing the overall purpose of the pull request>

### Details

<Detailed multi-line description in markdown format>
- Consolidated list of key changes
- Aggregated new features
- Combined refactoring details
- Other significant aspects from all descriptions
  "
}}

When generating the merged description:

- Create a concise yet comprehensive summary that captures the essence of all provided descriptions.
- Use markdown formatting in the detailed description for improved readability.
- Organize the details into relevant sections or bullet points, consolidating similar information from different descriptions.
- Focus on the most significant aspects of the changes across all descriptions.
- Eliminate redundancies and repetitions while ensuring all unique and important points are included.
- Ensure the output is in valid JSON format.

Analyze the provided PR descriptions thoroughly and generate a unified, comprehensive summary and detailed description. Use your expertise to identify, merge, and highlight the most important aspects of the changes across all descriptions. If certain details seem contradictory or unclear, use your best judgment to provide the most accurate and coherent representation of the pull request's purpose and changes.

Here is the information:
{DESCS}
"""

PR_DESC_EVALUATION_PROMPT = """
Please evaluate the accuracy and completeness of your previous responses in this conversation.
Identify any potential errors or areas for improvement.

Respond the JSON output as:
{{
  "desc": "
### Summary

<Brief one-line summary encompassing the overall purpose of the pull request>

### Details

<Detailed multi-line description in markdown format>
- Consolidated list of key changes
- Aggregated new features
- Combined refactoring details
- Other significant aspects from all descriptions
  "
}}

"""


PR_REVIEW_EVALUATION_PROMPT = """
Please evaluate the accuracy and completeness of your previous responses in this conversation.
Fix any potential errors or areas for improvement.

Generate a code review with feedback organized as a JSON object, including only sections with relevant feedback and omitting sections without feedback. Use the following structure:
{{
  "review": [
    {{
      "topic": "<SECTION_TOPIC>",
      "comment": "<CONSICE_COMMENT_ON_WHATS_THE_ISSUE>",
      "confidence": "<CONFIDENCE_LEVEL>",
      "reason": "<YOUR_REASON_FOR_COMMENTING_THIS_ISSUE>"
      "solution": "<SOLUTION_TO_THE_COMMENT>",
      "start_line": "<CODE_START_LINE_INTEGER>",
      "end_line": "<CODE_END_LINE_INTEGER>",
      "file_name": "<ABSOLUTE_CODE_FILE_PATH>",
      "request_for_change": "<NEEDS_UPDATE_IN_TRUE_OR_FALSE>"
    }},
    ...
  ]
}}

For "file_name" make sure to give the whole path so that developers can know exactly which file has issue.

Confidence Levels based on severity of the issue:
[
  "critical",
  "important",
  "moderate",
  "low",
  "trivial"
]

"""
